#
# spec file for package python-proto-plus
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%define modname proto_plus
%{?sle15_python_module_pythons}
Name:           python-proto-plus%{psuffix}
Version:        1.25.0
Release:        1.2
Summary:        Pythonic Protocol Buffers
License:        Apache-2.0
URL:            https://github.com/googleapis/proto-plus-python
Source0:        https://files.pythonhosted.org/packages/source/p/%{modname}/%{modname}-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module protobuf >= 3.19.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
# SECTION test requirements
%if %{with test}
BuildRequires:  %{python_module google-api-core >= 1.31.5}
BuildRequires:  %{python_module proto-plus}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytz}
%endif
# /SECTION
BuildRequires:  fdupes
Requires:       python-protobuf >= 3.19.0
BuildArch:      noarch
%python_subpackages

%description
This is a wrapper around protocol buffers. Protocol buffers is
a specification format for APIs, such as those inside Google.
This library provides protocol buffer message classes and objects
that largely behave like native Python types.

%prep
%autosetup -p1 -n %{modname}-%{version}

%build
%pyproject_wheel

%install
%if !%{with test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
# gh#googleapis/proto-plus-python#311
%pytest -k 'not (test_fields_mitigate_collision or test_dir or test_dir_message_base)'
%endif

%if !%{with test}
%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/proto
%{python_sitelib}/proto_plus-%{version}.dist-info
%endif

%changelog
* Fri Nov 22 2024 Markéta Machová <mmachova@suse.com>
- Update to 1.25.0
  * Add support for Python 3.13
  * Construct messages with nested struct
  * Fix 'Couldn't build proto file' when using Python 3.13
  * Fix conda compatibility issue
  * Fix issue with equality comparison of repeated field with None
  * Remove check for Protobuf version
- Drop merged pytest-staticmethod.patch
* Wed Oct  2 2024 Steve Kowalik <steven.kowalik@suse.com>
- Explicitly BuildRequires on pytz, the testsuite uses it.
* Thu Jun 20 2024 Dirk Müller <dmueller@suse.com>
- update to 1.24.0:
  * Add `always_print_fields_with_no_presence` fields to
    `to_json` and `to_dict`
  * Add compatibility with protobuf==5.x
  * AttributeError module 'google._upb._message' has no attribute
    'MessageMapContainer'
  * Deprecate field `including_default_value_fields` in `to_json`
    and `to_dict`
* Mon Feb 26 2024 Robert Schweikert <rjschwei@suse.com>
- Include in SLE 15 SP4 and later (jsc#PED-6697)
- Add %%{?sle15_python_module_pythons}
* Mon Jan  1 2024 Dirk Müller <dmueller@suse.com>
- update to 1.23.0:
  * Add additional parameters to `to_json()` and `to_dict()`
    methods (#384)
  * Add support for proto.__version__ (#393)
  * Add support for python 3.12 (#400)
  * Add documentation on how to query the current oneof in a
    given message (#408)
  * Add example for __protobuf__ module level attribute (#409)
* Tue Nov  7 2023 Matthias Fehring <buschmann23@opensuse.org>
- Update to 1.22.3
  * Resolve issue where marshal fails with cross api dependency
    (gh#googleapis/proto-plus-python#349)
* Fri Feb 24 2023 Daniel Garcia <daniel.garcia@suse.com>
- Update to 1.22.2
  * Add support for Python 3.11 (#329) (5cff3a0)
  * Fix typo in index.rst (#342) (a66a378)
* Fri Sep  9 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.22.1
  * Add no-pretty print option (#336)
- from version 1.22.0
  * Add support for protobuf v4 (#327)
  * Fix Timestamp, Duration and FieldMask marshaling
    in REST transport (a2e7300)
  * fixes bug in the test. (#332)
- from version 1.20.6
  * **deps:** allow protobuf < 5.0.0 (#324)
  * fix changelog header to consistent size (#319)
- from version 1.20.5
  * **deps:** require google-api-core[grpc] >= 1.31.5 (1d13c41)
  * **deps:** require protobuf>= 3.15.0, <4.0.0dev (#315)
- from version 1.20.4
  * default proto package name is the module name, not "" (#309)
  * lookup attribute instead of performing a deepcopy (#226)
- Update BuildRequires and Requires from setup.py
* Mon Apr 25 2022 Matej Cepl <mcepl@suse.com>
- Update to 1.20.3:
  - additional logic to mitigate collisions with reserved terms
  - dir(proto.Message) does not raise
  - mitigate collisions in field names
  - add custom dir for messages and message classes
  - workaround for buggy pytest
- Add pytest-staticmethod.patch which works around Pytest bug
  gh#pytest-dev/pytest#9637.
* Mon Jan 31 2022 Matthias Fehring <buschmann23@opensuse.org>
- update to 0.19.9
  * add pickling support to proto messages
    (gh#googleapis/proto-plus-python#280)
- from 0.19.8
  * fix typos
- from 0.19.7
  * restore allowing None as value for stringy ints
    (gh#googleapis/proto-plus-python#272)
- from 0.19.6
  * setting 64bit fields from strings supported
    (gh#googleapis/proto-plus-python#267)
- from 0.19.5
  * Clarify semantics of multiple oneof variants passed to msg ctor
- from 0.19.4
  * clarify that proto plus messages are not pickleable
- from 0.19.3
  * setting bytes field from python string base64 decodes before
    assignment (gh#googleapis/proto-plus-python#265)
- from 0.19.2
  * ensure enums are hashable (gh#googleapis/proto-plus-python#252)
- from 0.19.1
  * ensure enums are incomparable w other enum types
    (gh#googleapis/proto-plus-python#248)
* Thu Nov 11 2021 Steve Kowalik <steven.kowalik@suse.com>
- Add multibuild to defeat a build loop.
* Fri Sep 10 2021 Matthias Fehring <buschmann23@opensuse.org>
- update to 1.19.0
  * pass 'including_default_value_fields' through to 'Message.to_dict'
    method (gh#googleapis/proto-plus-python#232)
* Sat Mar 20 2021 Matthias Fehring <buschmann23@opensuse.org>
- update to 1.18.1
  * Add arm64 support for PY3.6 (gh#googleapis/proto-plus-python#219)
- from 1.18.0
  * add copy_from method for field assignment
    (gh#googleapis/proto-plus-python#512)
* Mon Mar 15 2021 Matthias Fehring <buschmann23@opensuse.org>
- update to 1.17.0
  * add preserving_proto_field_name to to_json (gh#googleapis/proto-plus-python#213)
- from 1.16.0
  * add preserving_proto_field_name passthrough in MessageMeta.to_dict
    (gh#googleapis/proto-plus-python#211)
- from 1.15.0
  * allow_alias fro enums (gh#googleapis/proto-plus-python#207)
- from 1.14.3
  * adding enums to a repeated field does not raise a TypeError
    (gh#googleapis/proto-plus-python#202)
- from 1.14.2
  * use the correct environment for uploading to pypi
- from 1.14.1
  * install the wheel dependency
- from 1.14.0
  * Features
    + Pypi publish ghub actions (gh#googleapis/proto-plus-python#189)
  * Bug Fixes
  * proper setitem and insert for RepeatedComposite
    (gh#googleapis/proto-plus-python#178)
  * proper native marshal for repeated enumeration fields
    (gh#googleapis/proto-plus-python#180)
- from 1.13.1
  * update docstring to match type hint (gh#googleapis/proto-plus-python#172)
* Wed Jan  6 2021 Matthias Fehring <buschmann23@opensuse.org>
- update to 1.13.0
  * add 3.9 support and drop 3.5
    (gh#googleapis/proto-plus-python#167)
- from 1.12.0
  * add default values parameter to to_json
    (gh#googleapis/proto-plus-python#162)
* Tue Oct 20 2020 Matthias Fehring <buschmann23@opensuse.org>
- initial package version 1.11.0
